Author: jonesde
Date: Fri Jul 20 23:44:51 2007
New Revision: 558257
URL:
http://svn.apache.org/viewvc?view=rev&rev=558257Log:
Small changes to use the system user instead of the admin user (system services should always use the system user) and to get party name data for cases where address.toName or address.attnName are empty
Modified:
ofbiz/trunk/specialpurpose/oagis/src/org/ofbiz/oagis/OagisShipmentServices.java
Modified: ofbiz/trunk/specialpurpose/oagis/src/org/ofbiz/oagis/OagisShipmentServices.java
URL:
http://svn.apache.org/viewvc/ofbiz/trunk/specialpurpose/oagis/src/org/ofbiz/oagis/OagisShipmentServices.java?view=diff&rev=558257&r1=558256&r2=558257==============================================================================
--- ofbiz/trunk/specialpurpose/oagis/src/org/ofbiz/oagis/OagisShipmentServices.java (original)
+++ ofbiz/trunk/specialpurpose/oagis/src/org/ofbiz/oagis/OagisShipmentServices.java Fri Jul 20 23:44:51 2007
@@ -252,7 +252,7 @@
MapStack bodyParameters = MapStack.create();
if (userLogin == null) {
try {
- userLogin = delegator.findByPrimaryKey("UserLogin", UtilMisc.toMap("userLoginId", "admin"));
+ userLogin = delegator.findByPrimaryKey("UserLogin", UtilMisc.toMap("userLoginId", "system"));
} catch (GenericEntityException e) {
Debug.logError(e, "Error getting userLogin", module);
}
@@ -341,8 +341,9 @@
bodyParameters.put("replacementReturnId", returnItem.getString("returnId"));
}
// tracking shipper account
String partyId = shipment.getString("partyIdTo");
+ bodyParameters.put("partyNameView", delegator.findByPrimaryKey("PartyNameView", UtilMisc.toMap("partyId", partyId)));
List partyCarrierAccounts = delegator.findByAnd("PartyCarrierAccount", UtilMisc.toMap("partyId", partyId));
partyCarrierAccounts = EntityUtil.filterByDate(partyCarrierAccounts);
if (partyCarrierAccounts != null) {
@@ -341,8 +341,9 @@
bodyParameters.put("replacementReturnId", returnItem.getString("returnId"));
}
- // tracking shipper account
+ // tracking shipper account, other Party info
String partyId = shipment.getString("partyIdTo");